==> gbook-0.5.tar.bz2: gbook/gbook.i18n-de.php <==
<?php

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "Name",
'f_origin'        => "Herkunft",
'f_ip'            => "IP",
'f_browser'       => "Browser",
'f_email'         => "E-Mail",
'f_homepage'      => "Homepage",
'f_captcha'       => "Captcha",
'f_entry'         => "Eintrag",
'f_ip'            => "IP",
'f_browser'       => "Browser",

# buttons
'b_submit'        => "eintragen",
'b_change'        => "ändern",
'b_delete'        => "löschen",
'b_reset'         => "zurücksetzen",

# misc
'headline'        => "Gästebuch",
'hl_create'       => "Erstellen eines neuen Eintrages:",
'hl_modify'       => "Ändern eines Eintrages:",
'new_entry'       => "Willkommen im Gästebuch, [[Special:Guestbook&action=add|'''hier''']] kann man neue Einträge erstellen.",
'entry_okay'      => "Okay, Dein Eintrag wurde hinzugefügt ;)",
'delete_okay'     => "Okay, der Eintrag wurde gelöscht.",
'change_okay'     => "Okay, der Eintrag wurde geändert.",
'show_entries'    => "Alle Einträge anzeigen",
'captcha_desc'    => "Bitte die Buchstaben und Ziffern aus der kleinen Grafik darunter eintippen.",
'captcha_fail'    => "Sorry, aber das Captcha stimmt nicht!",
'err_name'        => "Sorry, aber Dein Namen wird benötigt!",
'err_entry'       => "Sorry, aber Dein Eintrag scheint leer zu sein!",
'err_noentry'     => "Sorry, aber diesen Eintrag gibt es nicht!",
'err_captcha'     => "Sorry, aber das Captcha scheint leer zu sein!"
);

?>

==> gbook-0.6.tar.bz2: gbook/gbook.i18n-de.php <==
<?php

/**
 * Internationalisation file for the GuestBook extension
 *
 *
 * Copyright (C) 2005-2006 Tino Reichardt
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License Version 2, as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * @package MediaWiki
 * @subpackage Extensions
 * @author Tino Reichardt <milky dash gbook at mcmilk dot de>
 * @copyright © 2006 Tino Reichardt
 */


if (!defined('MEDIAWIKI')) die();

$msg = array(

# fields of the form
'f_name'          => "Name",
'f_origin'        => "Herkunft",
'f_ip'            => "IP",
'f_browser'       => "Browser",
'f_email'         => "E-Mail",
'f_homepage'      => "Homepage",
'f_captcha'       => "Captcha",
'f_entry'         => "Eintrag",
'f_ip'            => "IP",
'f_browser'       => "Browser",

# buttons
'b_submit'        => "eintragen",
'b_change'        => "ändern",
'b_delete'        => "löschen",
'b_reset'         => "zurücksetzen",

# misc
'headline'        => "Gästebuch",
'hl_create'       => "Erstellen eines neuen Eintrages:",
'hl_modify'       => "Ändern eines Eintrages:",
'new_entry'       => "Willkommen im Gästebuch, [{{fullurl:Special:Guestbook|action=add}} '''hier'''] kann man neue Einträge erstellen.",
'entry_okay'      => "Okay, Dein Eintrag wurde hinzugefügt ;)",
'delete_okay'     => "Okay, der Eintrag wurde gelöscht.",
'change_okay'     => "Okay, der Eintrag wurde geändert.",
'show_entries'    => "Alle Einträge anzeigen",
'captcha_desc'    => "Bitte die Buchstaben und Ziffern aus der kleinen Grafik darunter eintippen.",
'captcha_fail'    => "Sorry, aber das Captcha stimmt nicht!",
'err_name'        => "Sorry, aber Dein Namen wird benötigt!",
'err_entry'       => "Sorry, aber Dein Eintrag scheint leer zu sein!",
'err_noentry'     => "Sorry, aber diesen Eintrag gibt es nicht!",
'err_captcha'     => "Sorry, aber das Captcha scheint leer zu sein!"
);

?>
